@@ -1,18 +1,45 @@
-"""Particle quantities.
+"""Calculate quantities on the particles.
 
-Calculate various quantities on the particles.
+The following functions are available:
+
+- angular_momentum
+- angular_velocity
+- azimuthal_angle
+- dust_density
+- dust_fraction
+- dust_mass
+- eccentricity
+- gas_density
+- gas_fraction
+- gas_mass
+- inclination
+- keplerian_frequency
+- kinetic_energy
+- momentum
+- polar_angle
+- radial_distance
+- radial_velocity
+- semi_major_axis
+- specific_angular_momentum
+- specific_kinetic_energy
+- stokes_number
+- temperature
 """
 
-from typing import Any, Tuple, Union
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Any, Tuple, Union
 
 import numpy as np
 from numpy import ndarray
 
-from .. import Quantity
-from .. import units as plonk_units
-from ..snap import SnapLike
+from .._units import Quantity
+from .._units import units as plonk_units
 from ..utils.math import cross, norm
 
+if TYPE_CHECKING:
+    from ..snap.snap import SnapLike
+
 array_units = {
     'angular_momentum': 'angular_momentum',
     'angular_velocity': 'velocity',
