@@ -4,15 +4,19 @@ There are two functions: one for interpolation of scalar fields, and one
 for interpolation of vector fields.
 """
 
-from typing import Optional, Tuple
+from __future__ import annotations
+
+from typing import TYPE_CHECKING, Optional, Tuple
 
 import numpy as np
 from numpy import ndarray
 
-from ..snap import SnapLike
-from ..snap.snap import get_array_in_code_units
+from .._units import Quantity
 from .splash import interpolate_cross_section, interpolate_projection
 
+if TYPE_CHECKING:
+    from ..snap.snap import SnapLike
+
 Extent = Tuple[float, float, float, float]
 
 
@@ -377,3 +381,24 @@ def _get_arrays_from_str(*, snap, quantity, x, y):
             )
 
     return quantity, x, y, z
+
+
+def get_array_in_code_units(snap: SnapLike, name: str) -> ndarray:
+    """Get array in code units.
+
+    Parameters
+    ----------
+    snap
+        The Snap or SubSnap.
+    name
+        The array name.
+
+    Returns
+    -------
+    ndarray
+        The array on the particles in code units.
+    """
+    arr = snap[name]
+    if isinstance(arr, Quantity):
+        return (arr / snap.get_array_unit(name)).magnitude
+    return arr
